from .alb import ALBResponse as ALBResponse
from .api_gateway_authorizer import APIGatewayAuthorizerResponse
from .api_gateway_proxy import (
    APIGatewayProxyResponseV1 as APIGatewayProxyResponseV1,
)
from .api_gateway_proxy import (
    APIGatewayProxyResponseV2 as APIGatewayProxyResponseV2,
)
from .iot import (
    IoTPreProvisioningHookResponse as IoTPreProvisioningHookResponse,
)
from .kinesis_firehose import (
    KinesisFirehoseTransformationResponse as KinesisFirehoseTransformationResponse,
)
from .s3_batch import S3BatchResponse as S3BatchResponse
